@@ -70,7 +70,9 @@ def print_record(record: Record) -> None:
 @click.command()
 @click.argument("path", required=True)
 @click.option("--pid", default=None, help="Problem id.")
-@click.option("--json", default=False, help="Output in JSON format or not.", is_flag=True)
+@click.option(
+    "--json", default=False, help="Output in JSON format or not.", is_flag=True
+)
 def submit(path: str, pid: str, json: bool) -> None:
     """Submit a solution to Luogu."""
     path = os.path.abspath(path)
@@ -85,7 +87,9 @@ def submit(path: str, pid: str, json: bool) -> None:
     rid = submitter.submit(pid, open(path, "r").read())
     if not json:
         click.echo(
-            click.style(f"Solution submitted with record ID {rid}.", bold=True, fg="blue")
+            click.style(
+                f"Solution submitted with record ID {rid}.", bold=True, fg="blue"
+            )
         )
         click.echo(click.style("Compiling...", bold=True))
     record = submitter.get_record(rid)
@@ -102,7 +106,9 @@ def submit(path: str, pid: str, json: bool) -> None:
 
 @click.command()
 @click.argument("rid", required=True)
-@click.option("--json", default=False, help="Output in JSON format or not.", is_flag=True)
+@click.option(
+    "--json", default=False, help="Output in JSON format or not.", is_flag=True
+)
 def record(rid: str, json: bool) -> None:
     """Get a submition record by ID."""
     session = get_session()
